@@ -15,10 +15,8 @@ import java.awt.Color;
 import java.awt.Graphics2D;
 import java.awt.geom.Path2D;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Set;
 
-import org.scilab.forge.scirenderer.tranformations.Transformation;
 import org.scilab.forge.scirenderer.tranformations.Vector3d;
 
 /**
@@ -59,6 +57,9 @@ public abstract class AbstractDrawable3DObject {
         if (isDegenerate()) {
             throw new InvalidPolygonException("Invalid 3D Object: two vertices are the same");
         }
+        if (isNanOrInf()) {
+            throw new InvalidPolygonException("Invalid 3D Object: contains NaN or Inf coordinates");
+        }
         setPrecedence(defaultPrecedence++);
         bbox = BoundingBox.getBoundingBox(this);
         getNormal();
@@ -334,4 +335,30 @@ public abstract class AbstractDrawable3DObject {
 
         return degenerated;
     }
+
+    protected boolean isNanOrInf() {
+        for (Vector3d v : vertices) {
+            if (isNanOrInf(v)) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    public static final boolean isNanOrInf(final Vector3d v) {
+        final double x = v.getX();
+        if (Double.isNaN(x) || Double.isInfinite(x)) {
+            return true;
+        }
+        final double y = v.getY();
+        if (Double.isNaN(y) || Double.isInfinite(y)) {
+            return true;
+        }
+        final double z = v.getZ();
+        if (Double.isNaN(z) || Double.isInfinite(z)) {
+            return true;
+        }
+        return false;
+    }
 }
