@@ -16,9 +16,7 @@ import java.awt.Stroke;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.scilab.forge.scirenderer.DrawingTools;
 import org.scilab.forge.scirenderer.shapes.appearance.Appearance;
-import org.scilab.forge.scirenderer.shapes.geometry.Geometry;
 
 /**
  * @author Calixte DENIZET
