@@ -34,9 +34,7 @@ import org.scilab.forge.scirenderer.shapes.geometry.Geometry;
 import org.scilab.forge.scirenderer.shapes.geometry.Geometry.FaceCullingMode;
 import org.scilab.forge.scirenderer.texture.AnchorPosition;
 import org.scilab.forge.scirenderer.texture.Texture;
-import org.scilab.forge.scirenderer.tranformations.DegenerateMatrixException;
 import org.scilab.forge.scirenderer.tranformations.Transformation;
-import org.scilab.forge.scirenderer.tranformations.TransformationFactory;
 import org.scilab.forge.scirenderer.tranformations.Vector3d;
 
 /**
@@ -58,16 +56,23 @@ public class Motor3D {
      * @param dim the graphic dimensions
      */
     public Motor3D(G2DCanvas canvas, Graphics2D g2d, Dimension dim) {
-	this.canvas = canvas;
+        this.canvas = canvas;
         this.g2d = g2d;
         this.dim = dim;
         this.textureDrawingTools = new G2DTextureDrawingTools(g2d);
         AbstractDrawable3DObject.resetDefaultPrecedence();
-        //g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+    }
+
+    public void setAntialiased(boolean aa) {
+        if (aa) {
+            g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+        } else {
+            g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_OFF);
+        }
     }
 
     public boolean is2DView() {
-	return canvas.getMainDrawer().is2DView();
+        return canvas.getMainDrawer().is2DView();
     }
 
     public void setClippingPlanes(List<ClippingPlane> clippingPlanes) {
@@ -213,14 +218,16 @@ public class Motor3D {
      * @param tri the triangle to add
      */
     private void add(Triangle tri) {
-        Vector3d normal = tri.getNormal();
-        if (normal != null) {
-            //normal = transf.projectDirection(normal);
-            if ((mode == FaceCullingMode.CW && normal.getZ() > 0) || (mode == FaceCullingMode.CCW && normal.getZ() < 0) || mode == FaceCullingMode.BOTH) {
+        if (!is2DView() || tri.isIn2D()) {
+            Vector3d normal = tri.getNormal();
+            if (normal != null) {
+                //normal = transf.projectDirection(normal);
+                if ((mode == FaceCullingMode.CW && normal.getZ() > 0) || (mode == FaceCullingMode.CCW && normal.getZ() < 0) || mode == FaceCullingMode.BOTH) {
+                    Scene.addToRoot(is2DView(), tri);
+                }
+            } else {
                 Scene.addToRoot(is2DView(), tri);
             }
-        } else {
-            Scene.addToRoot(is2DView(), tri);
         }
     }
 
@@ -274,7 +281,7 @@ public class Motor3D {
         }
 
         if (textureCoords != null) {
-	    textureCoords.rewind();
+            textureCoords.rewind();
             if (textureCoords.hasArray()) {
                 buffer = textureCoords.array();
             } else {
@@ -311,7 +318,7 @@ public class Motor3D {
             textureCoordsArray = ta;
         }
 
-        return new Object[]{verticesArray, colorsArray, textureCoordsArray};
+        return new Object[] {verticesArray, colorsArray, textureCoordsArray};
     }
 
     /**
@@ -334,38 +341,42 @@ public class Motor3D {
             return;
         }
 
-        try {
-            switch (drawingMode) {
-            case SEGMENTS_STRIP :
-                for (int i = 0; i < verticesArray.length - 1; i++) {
-                    v = new Vector3d[]{verticesArray[i], verticesArray[i + 1]};
-                    c = new Color[]{colorsArray[i], colorsArray[i + 1]};
+        switch (drawingMode) {
+        case SEGMENTS_STRIP :
+            for (int i = 0; i < verticesArray.length - 1; i++) {
+                v = new Vector3d[] {verticesArray[i], verticesArray[i + 1]};
+                c = new Color[] {colorsArray[i], colorsArray[i + 1]};
+                try {
                     add(new Segment(v, c, stroke));
-                }
-                break;
-            case SEGMENTS_LOOP :
-                for (int i = 0; i < verticesArray.length - 1; i++) {
-                    v = new Vector3d[]{verticesArray[i], verticesArray[i + 1]};
-                    c = new Color[]{colorsArray[i], colorsArray[i + 1]};
-                    add(new Segment(v, c, stroke));
-                }
-                int n = verticesArray.length - 1;
-                v = new Vector3d[]{verticesArray[n], verticesArray[0]};
-                c = new Color[]{colorsArray[n], colorsArray[0]};
-                add(new Segment(v, c, stroke));
-                break;
-            case SEGMENTS :
-            default :
-                for (int i = 0; i < verticesArray.length - 1; i += 2) {
-                    v = new Vector3d[]{verticesArray[i], verticesArray[i + 1]};
-                    c = new Color[]{colorsArray[i], colorsArray[i + 1]};
-                    try {
-                        add(new Segment(v, c, stroke));
-                    } catch (InvalidPolygonException e) { }
-                }
-                break;
+                } catch (InvalidPolygonException e) { }
             }
-        } catch (InvalidPolygonException e) { }
+            break;
+        case SEGMENTS_LOOP :
+            for (int i = 0; i < verticesArray.length - 1; i++) {
+                v = new Vector3d[] {verticesArray[i], verticesArray[i + 1]};
+                c = new Color[] {colorsArray[i], colorsArray[i + 1]};
+                try {
+                    add(new Segment(v, c, stroke));
+                } catch (InvalidPolygonException e) { }
+            }
+            int n = verticesArray.length - 1;
+            v = new Vector3d[] {verticesArray[n], verticesArray[0]};
+            c = new Color[] {colorsArray[n], colorsArray[0]};
+            try {
+                add(new Segment(v, c, stroke));
+            } catch (InvalidPolygonException e) { }
+            break;
+        case SEGMENTS :
+        default :
+            for (int i = 0; i < verticesArray.length - 1; i += 2) {
+                v = new Vector3d[] {verticesArray[i], verticesArray[i + 1]};
+                c = new Color[] {colorsArray[i], colorsArray[i + 1]};
+                try {
+                    add(new Segment(v, c, stroke));
+                } catch (InvalidPolygonException e) { }
+            }
+            break;
+        }
     }
 
     /**
@@ -392,36 +403,36 @@ public class Motor3D {
         switch (drawingMode) {
         case TRIANGLE_FAN :
             for (int i = 1; i < verticesArray.length - 1; i++) {
-                v = new Vector3d[]{verticesArray[0], verticesArray[i], verticesArray[i + 1]};
-                c = new Color[]{colorsArray[0], colorsArray[i], colorsArray[i + 1]};
+                v = new Vector3d[] {verticesArray[0], verticesArray[i], verticesArray[i + 1]};
+                c = new Color[] {colorsArray[0], colorsArray[i], colorsArray[i + 1]};
                 try {
                     if (image == null) {
                         add(new Triangle(v, c, null));
                     } else {
-                        add(new Triangle(v, new Vector3d[]{textureCoordsArray[0], textureCoordsArray[i], textureCoordsArray[i + 1]}, image, filter));
+                        add(new Triangle(v, new Vector3d[] {textureCoordsArray[0], textureCoordsArray[i], textureCoordsArray[i + 1]}, image, filter));
                     }
                 } catch (InvalidPolygonException e) { }
             }
             int n = verticesArray.length - 1;
-            v = new Vector3d[]{verticesArray[0], verticesArray[n], verticesArray[1]};
-            c = new Color[]{colorsArray[0], colorsArray[n], colorsArray[1]};
+            v = new Vector3d[] {verticesArray[0], verticesArray[n], verticesArray[1]};
+            c = new Color[] {colorsArray[0], colorsArray[n], colorsArray[1]};
             try {
                 if (image == null) {
                     add(new Triangle(v, c, null));
                 } else {
-                    add(new Triangle(v, new Vector3d[]{textureCoordsArray[0], textureCoordsArray[n], textureCoordsArray[1]}, image, filter));
+                    add(new Triangle(v, new Vector3d[] {textureCoordsArray[0], textureCoordsArray[n], textureCoordsArray[1]}, image, filter));
                 }
             } catch (InvalidPolygonException e) { }
             break;
         case TRIANGLE_STRIP :
             for (int i = 0; i < verticesArray.length - 2; i++) {
-                v = new Vector3d[]{verticesArray[i], verticesArray[i + 1], verticesArray[i + 2]};
-                c = new Color[]{colorsArray[i], colorsArray[i + 1], colorsArray[i + 2]};
+                v = new Vector3d[] {verticesArray[i], verticesArray[i + 1], verticesArray[i + 2]};
+                c = new Color[] {colorsArray[i], colorsArray[i + 1], colorsArray[i + 2]};
                 try {
                     if (image == null) {
                         add(new Triangle(v, c, null));
                     } else {
-                        add(new Triangle(v, new Vector3d[]{textureCoordsArray[i], textureCoordsArray[i + 1], textureCoordsArray[i + 2]}, image, filter));
+                        add(new Triangle(v, new Vector3d[] {textureCoordsArray[i], textureCoordsArray[i + 1], textureCoordsArray[i + 2]}, image, filter));
                     }
                 } catch (InvalidPolygonException e) { }
             }
@@ -429,13 +440,13 @@ public class Motor3D {
         case TRIANGLES :
         default :
             for (int i = 0; i < verticesArray.length - 2; i += 3) {
-                v = new Vector3d[]{verticesArray[i], verticesArray[i + 1], verticesArray[i + 2]};
-                c = new Color[]{colorsArray[i], colorsArray[i + 1], colorsArray[i + 2]};
+                v = new Vector3d[] {verticesArray[i], verticesArray[i + 1], verticesArray[i + 2]};
+                c = new Color[] {colorsArray[i], colorsArray[i + 1], colorsArray[i + 2]};
                 try {
                     if (image == null) {
                         add(new Triangle(v, c, null));
                     } else {
-                        add(new Triangle(v, new Vector3d[]{textureCoordsArray[i], textureCoordsArray[i + 1], textureCoordsArray[i + 2]}, image, filter));
+                        add(new Triangle(v, new Vector3d[] {textureCoordsArray[i], textureCoordsArray[i + 1], textureCoordsArray[i + 2]}, image, filter));
                     }
                 } catch (InvalidPolygonException e) { }
             }
