@@ -19,10 +19,6 @@ import java.util.Set;
 import java.util.Stack;
 
 import org.scilab.forge.scirenderer.clipping.ClippingPlane;
-import org.scilab.forge.scirenderer.implementation.g2d.clipping.G2DClippingPlane;
-import org.scilab.forge.scirenderer.tranformations.Transformation;
-import org.scilab.forge.scirenderer.tranformations.Vector3d;
-import org.scilab.forge.scirenderer.tranformations.Vector4d;
 
 final class Scene {
 
@@ -77,7 +73,7 @@ final class Scene {
     }
 
     private static final void add(final boolean is2D, final ConvexObject object) {
-        synchronized(faces) {
+        synchronized (faces) {
             Scene st = new Scene(object);
             if (is2D) {
                 faces.add(st);
@@ -151,7 +147,7 @@ final class Scene {
     }
 
     static final void drawRoot(final Graphics2D g2d) {
-        synchronized(faces) {
+        synchronized (faces) {
             for (Scene face : disabledFaces) {
                 face.draw(g2d);
             }
@@ -165,21 +161,20 @@ final class Scene {
             }
 
             /*for (Scene face : faces) {
-                face.drawn = false;
-            }
+              face.drawn = false;
+              }
 
-            for (Scene face : faces) {
-                if (face.object.marked) {
-                    face.object.draw(g2d);
-                }
-		}*/
+              for (Scene face : faces) {
+              if (face.object.marked) {
+              face.object.draw(g2d);
+              }
+              }*/
         }
     }
 
     static final void clear() {
         disabledFaces.clear();
         faces.clear();
-        clippingPlanes = null;
         stack.clear();
     }
 
@@ -196,7 +191,6 @@ final class Scene {
                     face.draw(g2d);
                 }
             }
-
             object.draw(g2d);
             stack.pop();
         }
