@@ -14,7 +14,6 @@ package org.scilab.forge.scirenderer.implementation.g2d.motor;
 import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.Graphics2D;
-import java.awt.Polygon;
 import java.awt.RenderingHints;
 import java.awt.Stroke;
 import java.awt.geom.AffineTransform;
@@ -79,8 +78,13 @@ public class SpritedRectangle extends ConvexObject {
             Triangle t2 = new Triangle(v2, COLORS);
             t1.setSprite(this);
             t2.setSprite(this);
-            List<ConvexObject> list = o.breakObject(t1);
-            list.addAll(o.breakObject(t2));
+            List<ConvexObject> list = new ArrayList<ConvexObject>();
+            if (o.isBehind(t1) == 2) {
+                list.addAll(o.breakObject(t1));
+            }
+            if (o.isBehind(t2) == 2) {
+                list.addAll(o.breakObject(t2));
+            }
 
             return list;
         } catch (InvalidPolygonException e) { }
