@@ -20,6 +20,7 @@ import java.nio.FloatBuffer;
 /**
  * @author Pierre Lando
  */
+@SuppressWarnings(value = { "serial" })
 public class JoGLElementsBuffer extends JoGLDataBuffer implements ElementsBuffer {
 
     /**
@@ -285,4 +286,12 @@ public class JoGLElementsBuffer extends JoGLDataBuffer implements ElementsBuffer
             super("Bad vertex elements  size : " + size + ". Should be in [" + min + ", " + (max - 1) + "]");
         }
     }
+
+    @Override
+    public void clear() {
+        if (data != null) {
+            data.clear();
+        }
+        data = null;
+    }
 }
