@@ -14,6 +14,7 @@ package org.scilab.forge.scirenderer.implementation.jogl.texture;
 import com.jogamp.opengl.util.awt.TextureRenderer;
 import com.jogamp.opengl.util.texture.TextureCoords;
 
+import org.scilab.forge.scirenderer.DrawingTools;
 import org.scilab.forge.scirenderer.SciRendererException;
 import org.scilab.forge.scirenderer.buffers.ElementsBuffer;
 import org.scilab.forge.scirenderer.implementation.jogl.JoGLCanvas;
@@ -126,7 +127,8 @@ public class JoGLTextureManager implements TextureManager {
     @Override
     public void dispose(Texture texture) {
         if ((texture instanceof JoGLTexture) && (allTextures.contains((JoGLTexture) texture))) {
-            //((JoGLTexture) texture).dispose(); TODO.
+            ((JoGLTexture) texture).dispose();
+            allTextures.remove((JoGLTexture) texture);
         }
     }
 
@@ -135,6 +137,7 @@ public class JoGLTextureManager implements TextureManager {
      */
     public class JoGLTexture extends AbstractTexture implements Texture {
         private com.jogamp.opengl.util.texture.Texture[] textures;
+        private JoGLDrawingTools drawingTools;
         private int wCuts;
         private int hCuts;
         private double sfactor = 1;
@@ -146,12 +149,24 @@ public class JoGLTextureManager implements TextureManager {
         public JoGLTexture() {
         }
 
+        public void dispose() {
+            if (drawingTools != null) {
+                final GL2 gl = drawingTools.getGl().getGL2();
+                if (textures != null) {
+                    for (com.jogamp.opengl.util.texture.Texture t : textures) {
+                        t.destroy(gl);
+                    }
+                }
+            }
+        }
+
         /**
          * Bind the texture in the OpenGl context.
          * @param drawingTools current drawing tools.
          * @throws SciRendererException if the texture is invalid.
          */
         public void bind(JoGLDrawingTools drawingTools) throws SciRendererException {
+            this.drawingTools = drawingTools;
             GL2 gl = drawingTools.getGl().getGL2();
             if (isValid()) {
                 checkData(drawingTools);
@@ -251,6 +266,10 @@ public class JoGLTextureManager implements TextureManager {
 
             for (int k = 0; k < wCuts * hCuts; k++) {
                 textures[k].enable(gl);
+                textures[k].setTexParameteri(gl, GL2.GL_TEXTURE_MAG_FILTER, getAsGLFilter(getMagnificationFilter(), false));
+                textures[k].setTexParameteri(gl, GL2.GL_TEXTURE_MIN_FILTER, getAsGLFilter(getMinifyingFilter(), false));
+                textures[k].setTexParameteri(gl, GL2.GL_TEXTURE_WRAP_S, getAsGLWrappingMode(getSWrappingMode()));
+                textures[k].setTexParameteri(gl, GL2.GL_TEXTURE_WRAP_T, getAsGLWrappingMode(getTWrappingMode()));
                 textures[k].bind(gl);
             }
         }
