@@ -58,7 +58,7 @@ public class RulerDrawer {
     private RulerSpriteFactory spriteFactory;
 
     private OneShotRulerDrawer oneShotRulerDrawer;
-    
+
     /**
      * Ruler drawer constructor.
      * @param textureManager the {@link TextureManager} of the canvas where the ruler will be drawn.
@@ -96,9 +96,9 @@ public class RulerDrawer {
     public void disposeResources() {
         textureManager.dispose(spriteMap.values());
         spriteMap.clear();
+        oneShotRulerDrawer.dispose();
     }
 
-
     /**
      * This class actually perform all the rendering of one ruler.
      */
@@ -113,7 +113,7 @@ public class RulerDrawer {
          * Sprite Dimension map. Used as cached values in order not to charge DataProvider.
          */
         private Map<Double, Dimension> spriteDimensionMap = new HashMap<Double, Dimension>();
-        
+
         private List<PositionedSprite> spritesList = new LinkedList<PositionedSprite>();
 
         /**
@@ -131,7 +131,19 @@ public class RulerDrawer {
         private int density;
 
         public OneShotRulerDrawer() { }
-        
+
+        public void dispose() {
+            spriteDimensionMap.clear();
+            spritesList.clear();
+            if (subTicksValue != null) {
+                subTicksValue.clear();
+            }
+            if (ticksValue != null) {
+                ticksValue.clear();
+            }
+            rulerModel = null;
+        }
+
         /**
          * Constructor.
          * @param drawingTools the {@link DrawingTools} of the canvas where the ruler will be drawn.
@@ -142,7 +154,7 @@ public class RulerDrawer {
             subTicksValue = new LinkedList<Double>();
             ticksValue = new LinkedList<Double>();
             spritesList = new LinkedList<PositionedSprite>();
-            
+
             canvasProjection = drawingTools.getTransformationManager().getCanvasProjection();
 
             Vector3d windowTicksDirection = canvasProjection.projectDirection(rulerModel.getTicksDirection());
@@ -154,13 +166,13 @@ public class RulerDrawer {
 
             DecimalFormat format;
             if (rulerModel.isAutoTicks()) {
-            	format = computeAutoGraduation();
+                format = computeAutoGraduation();
             } else {
                 format = computeUserGraduation();
             }
             computeTicksData();
-        	draw(drawingTools);
-            
+            draw(drawingTools);
+
             double distRatio = computeTicksDistanceRatio(windowTicksDirection.getNorm());
 
             return new RulerDrawingResult(format, ticksValue, subTicksValue, density, distRatio, normalizedProjectedTicksDirection);
@@ -234,9 +246,9 @@ public class RulerDrawer {
                 for (double value : ticks) {
                     Texture sprite = computeSprite(value, format);
                     Vector3d windowPosition = canvasProjection.project(rulerModel.getPosition(value));
-                    
+
                     Dimension textureSize = computeSpriteDimension(value);
-                    
+
                     Vector3d delta = projectCenterToEdge(textureSize, windowTicksDelta);
                     PositionedSprite newSprite = new PositionedSprite(sprite, textureSize, windowPosition.plus(windowTicksDelta.plus(delta)));
                     newSpritesList.add(newSprite);
@@ -244,7 +256,7 @@ public class RulerDrawer {
                     Vector3d farDelta = windowTicksDelta.plus(delta.times(2.0));
                     currentMaximalSpritesDistance = Math.max(currentMaximalSpritesDistance, farDelta.getNorm());
                 }
-                
+
                 if (collide(newSpritesList, rulerModel.getMargin()) || collide(spritesList, newSpritesList, rulerModel.getMargin())) {
                     currentGraduations = currentGraduations.getAlternative();
                     canGetMore = false;
@@ -260,7 +272,7 @@ public class RulerDrawer {
                 }
             }
 
-            
+
             this.graduations = ticksGraduation;
             this.maximalSpritesDistance = maxSpritesDistance;
 
@@ -501,16 +513,16 @@ public class RulerDrawer {
         }
 
         private Dimension computeSpriteDimension(double value)
-        {
-        	Dimension spriteDimension = spriteDimensionMap.get(value);
-        	if (spriteDimension == null) {
-        		spriteDimension = spriteMap.get(value).getDataProvider().getTextureSize();
-        		spriteDimensionMap.put(value, spriteDimension);
-        	}
-        	
-        	return spriteDimension;
-        }
-        
+            {
+                Dimension spriteDimension = spriteDimensionMap.get(value);
+                if (spriteDimension == null) {
+                    spriteDimension = spriteMap.get(value).getDataProvider().getTextureSize();
+                    spriteDimensionMap.put(value, spriteDimension);
+                }
+
+                return spriteDimension;
+            }
+
         /**
          * This class is a basic container for a {@link Texture} and an associated window position.
          *
@@ -528,33 +540,33 @@ public class RulerDrawer {
              * @param windowPosition the window position.
              */
             public PositionedSprite(Texture sprite,  Vector3d windowPosition) {
-            	//long tic = Calendar.getInstance().getTimeInMillis();
-            	this.windowPosition = windowPosition;
+                //long tic = Calendar.getInstance().getTimeInMillis();
+                this.windowPosition = windowPosition;
                 this.sprite = sprite;
 
                 Dimension textureSize = sprite.getDataProvider().getTextureSize();
                 windowsBounds = new Rectangle2D.Double(
-                        windowPosition.getX(),
-                        windowPosition.getY(),
-                        textureSize.width,
-                        textureSize.height
-                );
-                
+                    windowPosition.getX(),
+                    windowPosition.getY(),
+                    textureSize.width,
+                    textureSize.height
+                    );
+
                 //System.err.println("====[new PositionedSprite] time = "+(Calendar.getInstance().getTimeInMillis() - tic));
             }
 
             public PositionedSprite(Texture sprite, Dimension textureSize, Vector3d windowPosition) {
-            	//long tic = Calendar.getInstance().getTimeInMillis();
-            	this.windowPosition = windowPosition;
+                //long tic = Calendar.getInstance().getTimeInMillis();
+                this.windowPosition = windowPosition;
                 this.sprite = sprite;
 
                 windowsBounds = new Rectangle2D.Double(
-                        windowPosition.getX(),
-                        windowPosition.getY(),
-                        textureSize.width,
-                        textureSize.height
-                );
-                
+                    windowPosition.getX(),
+                    windowPosition.getY(),
+                    textureSize.width,
+                    textureSize.height
+                    );
+
                 //System.err.println("====[new PositionedSprite] time = "+(Calendar.getInstance().getTimeInMillis() - tic));
             }
             /**
