@@ -17,6 +17,7 @@ import org.scilab.forge.scirenderer.shapes.appearance.Color;
 
 import javax.swing.Icon;
 import javax.swing.JLabel;
+import java.awt.AlphaComposite;
 import java.awt.Dimension;
 import java.awt.Graphics2D;
 import java.awt.RenderingHints;
@@ -61,10 +62,11 @@ public class BufferedImageTextureDrawingTools implements TextureDrawingTools {
      */
     public void accept(TextureDrawer textureDrawer) {
         g2d = image.createGraphics();
-        // Set transparent background.
-        g2d.setBackground(new java.awt.Color(0, 0, 0, 0));
-        g2d.clearRect(0, 0, image.getWidth(), image.getHeight());
-
+        g2d.setComposite(AlphaComposite.Src);
+        g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
+                             RenderingHints.VALUE_ANTIALIAS_ON);
+        g2d.setRenderingHint(RenderingHints.KEY_RENDERING,
+                             RenderingHints.VALUE_RENDER_QUALITY);
         g2d.transform(baseTransform);
 
         // Change center coordinate to (0, 0).
@@ -161,7 +163,7 @@ public class BufferedImageTextureDrawingTools implements TextureDrawingTools {
             g2d.setColor(textEntity.getTextColor());
             TextLayout textLayout = new TextLayout(textEntity.getText(), textEntity.getFont(), g2d.getFontRenderContext());
             Rectangle2D bounds = textLayout.getBounds();
-            textLayout.draw(g2d, (float) (x - bounds.getX()), (float) (y - bounds.getY()));
+            textLayout.draw(g2d, (float) (x + 1 - bounds.getX()), (float) (y + 1 - bounds.getY()));
         }
     }
 
@@ -175,7 +177,7 @@ public class BufferedImageTextureDrawingTools implements TextureDrawingTools {
         AffineTransform oldTransform = g2d.getTransform();
         g2d.setTransform(baseTransform);
         G2DShortCuts.useColor(g2d, color);
-        g2d.fillRect(0, 0, textureSize.width + 1, textureSize.height + 1);
+        g2d.fillRect(0, 0, textureSize.width, textureSize.height);
         g2d.setTransform(oldTransform);
     }
 
